@@ -30,13 +30,12 @@ class FolderView(BrowserView):
         portal = getUtility(IPloneSiteRoot)
         return ILeadImagePrefsForm(portal)
 
-    def tag(self, obj, css_class='tileImage'):
+    def tag(self, obj, scale="thumb" ,css_class='tileImage'):
 	if LEADIMAGE_EXISTS:
 	    context = aq_inner(obj)
 	    field = context.getField(IMAGE_FIELD_NAME)
 	    if field is not None:
 		if field.get_size(context) != 0:
-		    scale = self.prefs.desc_scale_name
 		    return field.tag(context, scale=scale, css_class=css_class)
 	    return ''
 	else:
@@ -133,12 +132,11 @@ class FolderView(BrowserView):
 		if leadMedia.portal_type == 'Image':
 		    return leadMedia.getURL() + '/image_%s'%scale
 		else:
-		    return None
+		    return self.tag(item, scale=scale)
 	    else:
-		return None
+		return self.tag(item, scale=scale)
 	else:
-	    #TODO: Add lead image support and News Item Image support
-	    return None
+	    return self.tag(item, scale=scale)
     
     def isVideo(self, item):
 	if FLOWPLAYER_EXISTS:
